.. _source_detection_step:

================
Source Detection
================

.. toctree::
   :maxdepth: 2

   description.rst
   arguments.rst
   psf.rst

.. automodapi:: romancal.source_detection
